.. _spider_zeit.diebin.at:

zeit.diebin.at
-------------------
Newest articles from `zeitdiebin <https://zeit.diebin.at/>`_.

Configuration
~~~~~~~~~~~~~
Add ``zeit.diebin.at`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     zeit.diebin.at
